@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.010';
+our $VERSION = '1.011';
 
 my %introduces = ( '5.030' => [qw[
                                   unicode12.1 uniprop_wildcards qr'N
@@ -237,7 +237,7 @@ Syntax::Construct - Explicitly state which non-feature constructs are used in th
 
 =head1 VERSION
 
-Version 1.010
+Version 1.011
 
 =head1 SYNOPSIS
 
@@ -790,7 +790,7 @@ explicit operator has been removed>.
 
 =head3 for-qw
 
-Removed in 5.18. See L<perl5180delta/https://metacpan.org/pod/perl5180delta#qw(...)-can-no-longer-be-used-as-parentheses>.
+Removed in 5.18. See L<perl5180delta/qw(...)-can-no-longer-be-used-as-parentheses>.
 
 =head3 @_=split
 
